# IronSnake
[![CI](https://github.com/ciaranra/ironsnake/actions/workflows/CI.yml/badge.svg)](https://github.com/ciaranra/ironsnake/actions/workflows/CI.yml)

IronSnake is an experimental project aimed at exploring advanced packaging of Rust and Python together.